@@ -1,6 +1,6 @@
 package App::Cerberus::Plugin::GeoIP;
 {
-  $App::Cerberus::Plugin::GeoIP::VERSION = '0.01';
+  $App::Cerberus::Plugin::GeoIP::VERSION = '0.02';
 }
 
 use strict;
@@ -51,7 +51,7 @@ App::Cerberus::Plugin::GeoIP - Add geo-location information the user's IP addres
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
@@ -96,11 +96,9 @@ You can do this as follows: (I'm assuming you have write permissions on C</opt>)
     tar -xzf GeoIP.tar.gz
     cd GeoIP-*/
 
-    libtoolize --f
+    libtoolize -f
     ./configure --prefix=/opt/geoip
-    make
-    make check
-    make install
+    make && make check && make install
 
 Then, find the latest version of L<Geo::IP> from L<https://metacpan.org/release/Geo-IP>
 and install it as follows:
@@ -111,9 +109,7 @@ and install it as follows:
     cd Geo-IP-*
 
     perl Makefile.PL LIBS='-L/opt/geoip/lib64' INC='-I/opt/geoip/include'
-    make
-    make test
-    make install
+    make && make test && make install
 
 You will also need a copy of the GeoLite City database:
 
